@@ -1,6 +1,9 @@
 from django.db import models
 from plicata.books.models import Book
 
+from mezzanine.core.models import Displayable, Ownable, RichText, Slugged
+from mezzanine.core.fields import FileField, RichTextField
+
 
 class Character(models.Model):
     name = models.CharField(max_length=80, unique=True)
@@ -9,9 +12,9 @@ class Character(models.Model):
     sortorder = models.IntegerField(default=999)
     visible = models.BooleanField(default=True)
     books = models.ManyToManyField(Book, blank=True,null=True, related_name='characters')
-    bioshort = models.CharField(max_length=500,blank=True,null=True)
-    biolong = models.TextField(blank=True,null=True)
-    excerpts = models.TextField(blank=True,null=True)
+    bioshort = models.RichTextField(max_length=500,blank=True,null=True)
+    biolong = models.RichTextField(blank=True,null=True)
+    excerpts = models.RichTextField(blank=True,null=True)
     def __unicode__(self):
         return self.name
 
